==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S37db707ef4875cd03a3e81050c508792.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "sconfig.h"
 
#if HAVE_SYS_TYPES_H
 
#include <sys/types.h>

#endif
 
#include "S06a0aa2da266b517aee369ac4d1a3d1d.h"

#if HAVE_STDIO_H
 
#include <stdio.h>

#endif
 class Se812b5a98988bad1d5b8df118cb6cc7f; class S749d2b576e15d77f0d14f186077e9ace; void S83ddf583b95468b5048422ccbeb5c056(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); bool Sea1776502570f06ddc0569c079cb9ee2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980);  void *Sa20bc1a55ab26242b4d4b78ddcd6b391(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S2e0edfa8ac0797ea56bafc77b0d3748b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980, bool Sf5cacf8a7ddd40a66b361df85e70b609, 
bool Se9100a7bcd5d0c8ff2b7089845a029b3); void Sdf58242fd0c7ef0217113f68d2799a5b(S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc, unsigned long S3a6d0284e743dc4a9b86f97d6dd1a3bf, unsigned char S4b3a6218bb3e3a7303e8a171a60fcf92); 
void Sd5304e91bf0ca46c9aebec9a5dc2688b(S2af226e5f5ad84cc1d032245701e80ce &S13b5bfe96f3e2fe411c9f66f4a582adf, 
unsigned long &S3a6d0284e743dc4a9b86f97d6dd1a3bf, unsigned char S4b3a6218bb3e3a7303e8a171a60fcf92); 
const char *S859fe0f4301b790aab395ad98cb602a5(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
Sbddd449e16d790b18d1b7e1319148fc2 *S736007832d2167baaae763fd3a3f3cf1, const char *S183f3fe79292a8d428a6160d1d44bd90, 
char S97e7b3cf2d1e0d8fad30b579ae7ae9fa); void Sfd1ffa93ed17c18a5140a665635e075d(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S183f3fe79292a8d428a6160d1d44bd90,  void *Sff81bde6255e9aadd881f0d164c20d53); 
bool S55d41376c299624c303339e53b1cbf7a(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980); bool Se29eafac061d4a6afb203c5a12634004(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S752b17460e72ccf9b0acb22aa3cacc7c, char Sfbf2f7672cc8bafc6adcd2d0212f4386, 
int S41275a535677f79ff347e01bc530c176); void Sb6d1dc0ab7f10b980ed5414ab2d78bb3(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, S749d2b576e15d77f0d14f186077e9ace &Sb9a15c6d632a44e7eb75d000e1dba40b, 
const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980); void Sd7f92a931252fb2153a037e8ab50b24e(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &Sb9a15c6d632a44e7eb75d000e1dba40b, 
const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980); void S06b98a6bc7a3ab7779416996eff4dc00(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); bool Sc54d60d5ff487c936cdcac962f33f18f(const S749d2b576e15d77f0d14f186077e9ace 
&Sd6fe1d0be6347b8ef2427fa629c04485); Sbddd449e16d790b18d1b7e1319148fc2 *S63e5463f547f5ea0c659417224c0a3e2(const 
char *S183f3fe79292a8d428a6160d1d44bd90); void Sc0d2065a212745d7fa205b8da6e781bf(Sbddd449e16d790b18d1b7e1319148fc2 
*S736007832d2167baaae763fd3a3f3cf1); void S20026f41a7fe98e583d0c8aff2705b3a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980); void S20026f41a7fe98e583d0c8aff2705b3a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980, bool Scd6f192618f2e44694a6484823132067); 
void S11d115c0cb7d51659d39a05e88942467(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980, bool Scd6f192618f2e44694a6484823132067); void Sf7ffeb350c9235cbf230290106a2d733(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, unsigned long S41275a535677f79ff347e01bc530c176); void Sd0349b0a34a283d36180513ce4f9a3ef(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); S749d2b576e15d77f0d14f186077e9ace Sdef0008dbcf272088d68f193d5bc92e1(const 
S749d2b576e15d77f0d14f186077e9ace &S03c7c0ace395d80182db07ae2c30f034); void Sce008598d7851b64fbf94d3f77f8563f(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S5c9f2d88d66278ac5b699ae88b3d2ab2, const char *Sb094188943aa15ee9da7c1357bc88eb5); 
void S02ac2f03c7799c1da25166f7bc933eb0(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const S749d2b576e15d77f0d14f186077e9ace &S55ef0b28593867d655a05a315a41595a, const S749d2b576e15d77f0d14f186077e9ace 
&S810074c074d526bf4bd3706296392b7b, bool S11e091eeb4139fcded06e20e7f1ce77b); void S07f996247a0254e6aea6c35b64ce6521(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sab5f8ca13aeb0692691e0cfc48dccdde, const char *Seefd02c65cec1bb4f546022b7f11ae3f, 
int S41275a535677f79ff347e01bc530c176); void Sdadfecad9a76a82a9e4ceed3d7ee893d(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S803ffc68f87e050b51e75f4d0338b509(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, void *S7f2db423a49b305459147332fb01cf87, unsigned long length, FILE 
*S8c7dd922ad47494fc02c388e12c00eac, const char *Sbe05d559ccc3262d3e7d034ed3c56980); void Sd7e084a98f918de99b45b9afe498bc96(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, FILE *S8c7dd922ad47494fc02c388e12c00eac, void *S7f2db423a49b305459147332fb01cf87, 
unsigned long Sde9c880e019a8efa914cceb070ec7253, const char *Sbe05d559ccc3262d3e7d034ed3c56980); void 
S6d1addede7cf1af8fab7f27509740518(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
FILE *S8c7dd922ad47494fc02c388e12c00eac, void *S7f2db423a49b305459147332fb01cf87, unsigned long Sea5273f98c146546ece478f217cf01c7, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980);

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S37db707ef4875cd03a3e81050c508792.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "sconfig.h"
 
#if HAVE_SYS_TYPES_H
 
#include <sys/types.h>

#endif
 
#include "S06a0aa2da266b517aee369ac4d1a3d1d.h"

#if HAVE_STDIO_H
 
#include <stdio.h>

#endif
 class Se812b5a98988bad1d5b8df118cb6cc7f; class S749d2b576e15d77f0d14f186077e9ace; void S83ddf583b95468b5048422ccbeb5c056(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); bool Sea1776502570f06ddc0569c079cb9ee2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980);  void *Sa20bc1a55ab26242b4d4b78ddcd6b391(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S2e0edfa8ac0797ea56bafc77b0d3748b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980, bool Sf5cacf8a7ddd40a66b361df85e70b609, 
bool Se9100a7bcd5d0c8ff2b7089845a029b3); void Sdf58242fd0c7ef0217113f68d2799a5b(S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc, unsigned long S3a6d0284e743dc4a9b86f97d6dd1a3bf, unsigned char S4b3a6218bb3e3a7303e8a171a60fcf92); 
void Sd5304e91bf0ca46c9aebec9a5dc2688b(S2af226e5f5ad84cc1d032245701e80ce &S13b5bfe96f3e2fe411c9f66f4a582adf, 
unsigned long &S3a6d0284e743dc4a9b86f97d6dd1a3bf, unsigned char S4b3a6218bb3e3a7303e8a171a60fcf92); 
const char *S859fe0f4301b790aab395ad98cb602a5(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
Sbddd449e16d790b18d1b7e1319148fc2 *S736007832d2167baaae763fd3a3f3cf1, const char *S183f3fe79292a8d428a6160d1d44bd90, 
char S97e7b3cf2d1e0d8fad30b579ae7ae9fa); void Sfd1ffa93ed17c18a5140a665635e075d(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S183f3fe79292a8d428a6160d1d44bd90,  void *Sff81bde6255e9aadd881f0d164c20d53); 
bool S55d41376c299624c303339e53b1cbf7a(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980); bool Se29eafac061d4a6afb203c5a12634004(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S752b17460e72ccf9b0acb22aa3cacc7c, char Sfbf2f7672cc8bafc6adcd2d0212f4386, 
int S41275a535677f79ff347e01bc530c176); void Sb6d1dc0ab7f10b980ed5414ab2d78bb3(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, S749d2b576e15d77f0d14f186077e9ace &Sb9a15c6d632a44e7eb75d000e1dba40b, 
const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980); void Sd7f92a931252fb2153a037e8ab50b24e(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &Sb9a15c6d632a44e7eb75d000e1dba40b, 
const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980); void Sd46a7331038631250dcf707eb505caa1(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &Sb9a15c6d632a44e7eb75d000e1dba40b, 
const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980, bool S901a3b4b8a0b5a7ce68f7d02b75b2b0e); 
void S06b98a6bc7a3ab7779416996eff4dc00(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
bool Sc54d60d5ff487c936cdcac962f33f18f(const S749d2b576e15d77f0d14f186077e9ace &Sd6fe1d0be6347b8ef2427fa629c04485); 
Sbddd449e16d790b18d1b7e1319148fc2 *S63e5463f547f5ea0c659417224c0a3e2(const char *S183f3fe79292a8d428a6160d1d44bd90); 
void Sc0d2065a212745d7fa205b8da6e781bf(Sbddd449e16d790b18d1b7e1319148fc2 *S736007832d2167baaae763fd3a3f3cf1); 
void S20026f41a7fe98e583d0c8aff2705b3a(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980); void S20026f41a7fe98e583d0c8aff2705b3a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sbe05d559ccc3262d3e7d034ed3c56980, bool Scd6f192618f2e44694a6484823132067); 
void S11d115c0cb7d51659d39a05e88942467(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980, bool Scd6f192618f2e44694a6484823132067); void Sf7ffeb350c9235cbf230290106a2d733(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, unsigned long S41275a535677f79ff347e01bc530c176); void Sd0349b0a34a283d36180513ce4f9a3ef(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); S749d2b576e15d77f0d14f186077e9ace Sdef0008dbcf272088d68f193d5bc92e1(const 
S749d2b576e15d77f0d14f186077e9ace &S03c7c0ace395d80182db07ae2c30f034); void Sce008598d7851b64fbf94d3f77f8563f(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S5c9f2d88d66278ac5b699ae88b3d2ab2, const char *Sb094188943aa15ee9da7c1357bc88eb5); 
void S02ac2f03c7799c1da25166f7bc933eb0(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const S749d2b576e15d77f0d14f186077e9ace &S55ef0b28593867d655a05a315a41595a, const S749d2b576e15d77f0d14f186077e9ace 
&S810074c074d526bf4bd3706296392b7b, bool S11e091eeb4139fcded06e20e7f1ce77b); void S07f996247a0254e6aea6c35b64ce6521(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sab5f8ca13aeb0692691e0cfc48dccdde, const char *Seefd02c65cec1bb4f546022b7f11ae3f, 
int S41275a535677f79ff347e01bc530c176); void Sdadfecad9a76a82a9e4ceed3d7ee893d(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S803ffc68f87e050b51e75f4d0338b509(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, void *S7f2db423a49b305459147332fb01cf87, unsigned long length, FILE 
*S8c7dd922ad47494fc02c388e12c00eac, const char *Sbe05d559ccc3262d3e7d034ed3c56980); void Sd7e084a98f918de99b45b9afe498bc96(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, FILE *S8c7dd922ad47494fc02c388e12c00eac, void *S7f2db423a49b305459147332fb01cf87, 
unsigned long Sde9c880e019a8efa914cceb070ec7253, const char *Sbe05d559ccc3262d3e7d034ed3c56980); void 
S6d1addede7cf1af8fab7f27509740518(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
FILE *S8c7dd922ad47494fc02c388e12c00eac, void *S7f2db423a49b305459147332fb01cf87, unsigned long Sea5273f98c146546ece478f217cf01c7, 
const char *Sbe05d559ccc3262d3e7d034ed3c56980);
